ApiResponse<T> class
Properties
-
code
→ int
-
final
-
data
↔ T?
-
getter/setter pair
-
e
↔ Object?
-
getter/setter pair
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
msg
↔ String?
-
getter/setter pair
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
-
total
↔ int?
-
getter/setter pair
Methods
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited