RequestInterface<T, K> class abstract

Implementers

Constructors

RequestInterface()

Properties

data Object?
no setter
hashCode int
The hash code for this object.
no setterinherited
method DioMethod
no setter
option → Options?
no setter
path String
no setter
queryParameters Map<String, dynamic>?
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

cancel([Object? reason]) → void
execute() Future<ApiResponse<T>>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited