JSBaseRequest<T, K> class
- Inheritance
-
- Object
- RequestInterface<
T, K> - JSBaseRequest
Constructors
Properties
- data → Object?
-
no setteroverride
- fromJson → T Function(K)
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- method → DioMethod
-
no setteroverride
- option → Options?
-
no setteroverride
- path → String
-
no setteroverride
-
queryParameters
→ Map<
String, dynamic> ? -
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- timeout → Duration
-
final
- url ↔ String
-
getter/setter pair
Methods
-
cancel(
[Object? reason]) → void -
inherited
-
convert(
dynamic data) → T? -
execute(
{Dio? dio}) → Future< ApiResponse< T> > -
override
-
handleException(
DioResult? data) → ApiResponse< T> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
validate(
DioResult? response) → int
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited